@@ -178,7 +178,7 @@ class mysql(object):
 			data=cur.fetchall() if is_query else cur.lastrowid
 		is_query or self.conn.commit()
 		return data
-	def add(self,dicts,table=None):
+	def add(self,dicts,table=None,ignore=False):
 		'''table is optional,dicts can be list or dict'''
 		if not isinstance(table,str):
 			if table is None:
@@ -193,7 +193,8 @@ class mysql(object):
 		for x in dicts:
 			key,value=self._split_add_dict(x)
 			values+=r'(%s),'%(value)
-		return self.execute(r''' insert `%s`(%s) values%s '''%(table,key,values[:-1]))
+		ignore='' if not ignore else 'ignore'
+		return self.execute(f''' insert {ignore} `{table}`({key}) values{values[:-1]} ''')
 	def update(self,where,data,table=None):
 		'''where can be str or dict'''
 		table=self.table if table is None else table
